==> zio-aws-route53resolver_3-5.17.144.1-sources.jar: zio/aws/route53resolver/model/DisassociateResolverRuleResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DisassociateResolverRuleResponse(
    resolverRuleAssociation: Option[
      zio.aws.route53resolver.model.ResolverRuleAssociation
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.DisassociateResolverRuleResponse = {
    import DisassociateResolverRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.DisassociateResolverRuleResponse
      .builder()
      .optionallyWith(
        resolverRuleAssociation.map(value => value.buildAwsValue())
      )(_.resolverRuleAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.DisassociateResolverRuleResponse.ReadOnly =
    zio.aws.route53resolver.model.DisassociateResolverRuleResponse
      .wrap(buildAwsValue())
}
object DisassociateResolverRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.DisassociateResolverRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.DisassociateResolverRuleResponse =
      zio.aws.route53resolver.model.DisassociateResolverRuleResponse(
        resolverRuleAssociation.map(value => value.asEditable)
      )
    def resolverRuleAssociation
        : Option[zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly]
    def getResolverRuleAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "resolverRuleAssociation",
      resolverRuleAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.DisassociateResolverRuleResponse
  ) extends zio.aws.route53resolver.model.DisassociateResolverRuleResponse.ReadOnly {
    override val resolverRuleAssociation: Option[
      zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly
    ] = scala
      .Option(impl.resolverRuleAssociation())
      .map(value =>
        zio.aws.route53resolver.model.ResolverRuleAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.DisassociateResolverRuleResponse
  ): zio.aws.route53resolver.model.DisassociateResolverRuleResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53resolver_3-5.17.195.1-sources.jar: zio/aws/route53resolver/model/DisassociateResolverRuleResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DisassociateResolverRuleResponse(
    resolverRuleAssociation: Optional[
      zio.aws.route53resolver.model.ResolverRuleAssociation
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.DisassociateResolverRuleResponse = {
    import DisassociateResolverRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.DisassociateResolverRuleResponse
      .builder()
      .optionallyWith(
        resolverRuleAssociation.map(value => value.buildAwsValue())
      )(_.resolverRuleAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.DisassociateResolverRuleResponse.ReadOnly =
    zio.aws.route53resolver.model.DisassociateResolverRuleResponse
      .wrap(buildAwsValue())
}
object DisassociateResolverRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.DisassociateResolverRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.DisassociateResolverRuleResponse =
      zio.aws.route53resolver.model.DisassociateResolverRuleResponse(
        resolverRuleAssociation.map(value => value.asEditable)
      )
    def resolverRuleAssociation: Optional[
      zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly
    ]
    def getResolverRuleAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "resolverRuleAssociation",
      resolverRuleAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.DisassociateResolverRuleResponse
  ) extends zio.aws.route53resolver.model.DisassociateResolverRuleResponse.ReadOnly {
    override val resolverRuleAssociation: Optional[
      zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.resolverRuleAssociation())
      .map(value =>
        zio.aws.route53resolver.model.ResolverRuleAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.DisassociateResolverRuleResponse
  ): zio.aws.route53resolver.model.DisassociateResolverRuleResponse.ReadOnly =
    new Wrapper(impl)
}
